AmCharts.translations[ "export" ][ "lt" ] = {
	"fallback.save.text": "Spauskite CTRL + C jei norite nukopijuoti paveiksliuką.",
	"fallback.save.image": "Spragtelkite dešinį klavišą ir pasirinkite \"Save picture as...\" jei norite išsaugoti paveiksliuką.",

	"capturing.delayed.menu.label": "{{duration}}",
	"capturing.delayed.menu.title": "Nutraukti",

	"menu.label.print": "Spausdinti",
	"menu.label.undo": "Atšaukti",
	"menu.label.redo": "Pakartoti",
	"menu.label.cancel": "Nutraukti",

	"menu.label.save.image": "Atsisiųsti ...",
	"menu.label.save.data": "Išsaugoti ...",

	"menu.label.draw": "Anotuoti ...",
	"menu.label.draw.change": "Keisti ...",
	"menu.label.draw.add": "Pridėti ...",
	"menu.label.draw.shapes": "Ikonėlę ...",
	"menu.label.draw.colors": "Spalvą ...",
	"menu.label.draw.widths": "Teptuką ...",
	"menu.label.draw.opacities": "Nepermatomumas ...",
	"menu.label.draw.text": "Tekstą",

	"menu.label.draw.modes": "Režimas ...",
	"menu.label.draw.modes.pencil": "Tekstą",
	"menu.label.draw.modes.line": "Linija",
	"menu.label.draw.modes.arrow": "Rodyklė",

	"label.saved.from": "Išsaugoti nuo: "
}